@@ -15,8 +15,8 @@ emmeans(nutr.lm, ~ group * race, calc = c(n = ".wgt."))
 with(nutrition, table(race, age))
 
 ## -----------------------------------------------------------------------------
-summary(emmeans(nutr.lm, pairwise ~ group | race, at = list(age = "3")), 
-    by = NULL)
+emmeans(nutr.lm, pairwise ~ group | race, at = list(age = "3")) |>
+    summary(by = NULL)
 
 ## -----------------------------------------------------------------------------
 framing <- mediation::framing 
@@ -39,15 +39,42 @@ emmip(framing.glm, treat ~ educ | gender, type = "response",
 
 ## ----eval = FALSE-------------------------------------------------------------
 #  emmeans(model, "A", weights = "outer")
-#  emmeans(emmeans(model, c("A", "B"), weights = "prop"),  weights = "prop")
+#  emmeans(model, c("A", "B"), weights = "prop") |>  emmeans(weights = "prop")
 
 ## ----message = FALSE----------------------------------------------------------
-sapply(c("equal", "prop", "outer", "cells", "flat"), function(w)
-    predict(emmeans(nutr.lm, ~ race, weights = w)))
+sapply(c("equal", "prop", "outer", "cells", "flat"), \(w)
+    emmeans(nutr.lm, ~ race, weights = w) |> predict())
 
 ## -----------------------------------------------------------------------------
-summary(emmeans(nutr.lm, pairwise ~ group | race, submodel = ~ age + group*race), 
-        by = NULL)
+mtcars.lm <- lm(mpg ~ factor(cyl)*am + disp + hp + drat + log(wt) + vs + 
+                  factor(gear) + factor(carb), data = mtcars)
+
+## -----------------------------------------------------------------------------
+rg.usual <- ref_grid(mtcars.lm)
+rg.usual
+nrow(rg.usual@linfct)
+rg.nuis = ref_grid(mtcars.lm, non.nuisance = "cyl")
+rg.nuis
+nrow(rg.nuis@linfct)
+
+## -----------------------------------------------------------------------------
+emmeans(rg.usual, ~ cyl * am)
+emmeans(rg.nuis, ~ cyl * am)
+
+## -----------------------------------------------------------------------------
+predict(emmeans(mtcars.lm, ~ cyl * am, non.nuis = c("cyl", "am"), 
+                wt.nuis = "prop"))
+predict(emmeans(mtcars.lm, ~ cyl * am, weights = "outer"))
+
+## -----------------------------------------------------------------------------
+emmeans(mtcars.lm, ~ gear | am, non.nuis = quote(all.vars(specs)))
+
+## ---- error = TRUE------------------------------------------------------------
+ref_grid(mtcars.lm, rg.limit = 200)
+
+## -----------------------------------------------------------------------------
+emmeans(nutr.lm, pairwise ~ group | race, submodel = ~ age + group*race) |> 
+        summary(by = NULL)
 
 ## -----------------------------------------------------------------------------
 emmeans(nutr.lm, ~ group * race, submodel = "minimal")
@@ -55,9 +82,6 @@ emmeans(nutr.lm, ~ group * race, submodel = "minimal")
 ## -----------------------------------------------------------------------------
 joint_tests(nutr.lm, submodel = "type2")
 
-## -----------------------------------------------------------------------------
-car::Anova(nutr.lm)
-
 ## -----------------------------------------------------------------------------
 cows <- data.frame (
     route = factor(rep(c("injection", "oral"), c(5, 9))),
